@@ -7,16 +7,16 @@ module FactoryBot
       :inline_sequences,
       :sequences,
       :strategies,
-      :traits,
+      :traits
     )
 
     def initialize
-      @factories      = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Factory"))
-      @sequences      = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Sequence"))
-      @traits         = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Trait"))
-      @strategies     = Registry.new("Strategy")
+      @factories = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Factory"))
+      @sequences = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Sequence"))
+      @traits = Decorator::DisallowsDuplicatesRegistry.new(Registry.new("Trait"))
+      @strategies = Registry.new("Strategy")
       @callback_names = Set.new
-      @definition     = Definition.new(:configuration)
+      @definition = Definition.new(:configuration)
       @inline_sequences = []
 
       to_create(&:save!)
