@@ -1,15 +1,15 @@
 describe "attribute aliases" do
   before do
-    define_model('User', name: :string, age: :integer)
+    define_model("User", name: :string, age: :integer)
 
-    define_model('Post', user_id: :integer) do
+    define_model("Post", user_id: :integer) do
       belongs_to :user
     end
 
     FactoryBot.define do
       factory :user do
         factory :user_with_name do
-          name "John Doe"
+          name { "John Doe" }
         end
       end
 
