@@ -1,5 +1,5 @@
-if RUBY_VERSION >= "3.0" && RUBY_ENGINE != "truffleruby"
-  require_relative "./attributes_for_destructuring"
+if RUBY_ENGINE != "truffleruby"
+  require_relative "attributes_for_destructuring"
 end
 
 describe "a generated attributes hash" do
