@@ -1,7 +1,7 @@
 RSpec::Matchers.define :have_trait do |trait_name|
   match do |instance|
     instance.defined_traits.any? do |trait|
-      trait.name == trait_name && trait.send(:block) == @block
+      trait.name == trait_name.to_s && trait.send(:block) == @block
     end
   end
 
